@@ -16,5 +16,5 @@ def plot_comparison_pipelines(pipelines):
     PipelineProfiler.plot_pipeline_matrix(pipelines)
 
 
-def plot_text_summary(dataset, category_column, text_column):
-    VisualTextAnalyzer.plot_text_summary(dataset, category_column=category_column, text_column=text_column)
+def plot_text_summary(dataset, text_column, label_column):
+    VisualTextAnalyzer.plot_text_summary(dataset, text_column=text_column, category_column=label_column)
